package dummy_test

import (
	. "launchpad.net/gocheck"
	_ "launchpad.net/juju-core/environs/dummy"
	"launchpad.net/juju-core/environs/jujutest"
	"launchpad.net/juju-core/testing"
	stdtesting "testing"
)

type liveTestSuite struct {
	testing.FakeRootSuite
	jujutest.LiveTests
}

type testSuite struct {
	testing.FakeRootSuite
	jujutest.Tests
}

func init() {
	attrs := map[string]interface{}{
		"name":         "only",
		"type":         "dummy",
		"state-server": true,
		"secret":       "pork",
		"admin-secret": "fish",
	}
	Suite(&liveTestSuite{
		LiveTests: jujutest.LiveTests{
			Config:         attrs,
			CanOpenState:   true,
			HasProvisioner: false,
		},
	})
	Suite(&testSuite{
		Tests: jujutest.Tests{
			Config: attrs,
		},
	})
}

func (s *liveTestSuite) SetUpSuite(c *C) {
	s.FakeRootSuite.SetUpSuite(c)
	s.FakeRootSuite.SetUpTest(c) // Use a fake root for the entire suite of tests.
	s.LiveTests.SetUpSuite(c)
}

func (s *liveTestSuite) TearDownSuite(c *C) {
	s.LiveTests.TearDownSuite(c)
	s.FakeRootSuite.TearDownTest(c)
	s.FakeRootSuite.TearDownSuite(c)
}

func (s *liveTestSuite) SetUpTest(c *C) {
	s.LiveTests.SetUpTest(c)
}

func (s *liveTestSuite) TearDownTest(c *C) {
	s.LiveTests.TearDownTest(c)
}

func (s *testSuite) SetUpSuite(c *C) {
	s.FakeRootSuite.SetUpSuite(c)
	s.Tests.SetUpSuite(c)
}

func (s *testSuite) TearDownSuite(c *C) {
	s.Tests.TearDownSuite(c)
	s.FakeRootSuite.TearDownSuite(c)
}

func (s *testSuite) SetUpTest(c *C) {
	s.FakeRootSuite.SetUpTest(c)
	s.Tests.SetUpTest(c)
}

func (s *testSuite) TearDownTest(c *C) {
	s.Tests.TearDownTest(c)
	s.FakeRootSuite.TearDownTest(c)
}

func TestSuite(t *stdtesting.T) {
	testing.MgoTestPackage(t)
}
